@@ -1,3 +1,3 @@
 from .density_profile import density_profile, density_path
 from .single_output import nmf2, nmf2_storm, hmf2, hmf1
-# from .update import update_echaim_data
+from .update import update
\ No newline at end of file
