@@ -8,11 +8,8 @@
 #include <string.h>
 #include "sqlite3.h"
 #include "ECHAIM.h"
-#include "getDir.h"
 #include "global.h"
 
-#include <omp.h>
-
 void print_d_array(double *arr, int len) {
     for (int j = 0; j < len; j++) {
         printf("%4.3e ", arr[j]);
